body {
  padding-top: 60px; /* 60px to make the container go all the way to the bottom of the topbar */
}
blockquote p {
  margin-bottom: 10px;
}
footer {
  background: #f9f9f9;
  color: #666;
  font-size: 0.9em;
  text-align: center;
  padding: 30px;
}
footer a {
  font-weight: bold;
}
.brand small {
  color: #999;
  font-size: 0.7em;
}
.brand:hover {
  color: #08C;
}
.meta {
  color: #888;
}
.increase {
  color: red;
}
.decrease {
  color: green;
}
.sparktooltip {
  position: absolute;
  left: 0;
  top: 0;
  visibility: hidden;
  opacity: 0.8;
  filter: alpha(opacity=80);
  font-size: 0.9em;
  max-width: 200px;
  padding: 8px;
  color: #ffffff;
  text-align: center;
  text-decoration: none;
  background-color: #000000;
  -webkit-border-radius: 4px;
     -moz-border-radius: 4px;
          border-radius: 4px;

}
.sparktooltip caption {
  font-weight: bold;
  color: orange;
}

.sparktooltip table {
  border-spacing: none;
}
.sparktooltip table th,
.sparktooltip table td {
  padding: 3px;
  line-height: 1em;
}
.sparktooltip table th {
  text-align: right;
}
.sparktooltip table td {
  text-align: left;
}
.change-increase {
  color: red;
}
.change-decrease {
  color: green;
}
.trace-diff {
}
.trace-diff td div {
  width: 460px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.trace-diff td .indent {
  display: inline-block;
  width: 2px;
}
.diff-delete {
  color: red;
}
.diff-insert {
  color: green;
}
.diff-replace {
  color: blue;
}
ul.traceback {
  list-style-type: none;
  margin-left: 0;
}
ul.traceback li.frame {
  margin-bottom: 1em;
  overflow: hidden;
  position: relative;
}
ul.traceback code {
  background: inherit;
  border: none;
  color: #000;
}
ol.context {
  margin: 0;
  list-style-position: inside;
  border: 1px solid #ccc;
  border: 1px solid rgba(0,0,0,.15);
  .border-radius(3px);
}
ol.context li {
  padding-left: 20px;
  font-family:monospace;
  white-space:pre;
  color:rgba(0,0,0,.75);
  background-color: #f5f5f5;
}
ol.context li pre {
  background-color: inherit;
  color: rgba(0,0,0,.5);
  margin: 0;
  padding: 0;
  border: 0;
  display: inline;
  font-size: 12px;
  white-space: pre;
  white-space: pre-wrap;
  word-wrap: break-word;
}
ol.context li.active {
  background-color: #ddd;
}
ol.context li.active pre {
  color: #000;
}
ol.context-line li span {
  float: right;
}

.expandable {
  cursor: pointer;
}
.expandable .closed {
  height: 0;
  overflow: hidden;
}

.modal {
  overflow: none;
  margin-top: -350px;
  width: 800px;
  margin-left: -400px;
}
.modal-body {
  max-height: 600px;
}