<dl class="dl-horizontal">
  <dt>ID</dt>
  <dd><a href="{% url zumanji:view_build project_label=build.project.label build_id=build.id %}">#{{ build.id }}</a></dd>
  <dt>Project</dt>
  <dd><a href="{% url zumanji:view_project project_label=build.project.label %}">{{ build.project.label }}</a></dd>
  <dt>Revision</dt>
  <dd>{{ build.revision.label }}</dd>
  <dt>Duration:</dt>
  <dd>{{ build.total_duration|floatformat:3 }}s</dd>
  <dt>Tests:</dt>
  <dd>{{ build.num_tests }}</dd>
  <dt>Datetime</dt>
  <dd>{{ build.datetime }}</dd>
  <dt>Tags</dt>
  <dd>
    {% for tag in build.tags.all %}
      <a href="{% url zumanji:view_tag project_label=build.project.label, tag_id=tag.id %}">{{ tag.label }}</a>{% if not forloop.last %}, {% endif %}
    {% endfor %}
  </dd>
</dl>