

<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>Zumanji</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- Le styles -->
    <link href="{{ STATIC_URL }}zumanji/css/bootstrap.css" rel="stylesheet">
    <link href="{{ STATIC_URL }}zumanji/css/bootstrap-responsive.css" rel="stylesheet">
    <link href="{{ STATIC_URL }}zumanji/css/zumanji.css" rel="stylesheet">

    <!-- Le HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->

    <script src="{{ STATIC_URL }}zumanji/js/jquery-1.8.0.js"></script>
    <script src="{{ STATIC_URL }}zumanji/js/bootstrap.js"></script>
    <script src="{{ STATIC_URL }}zumanji/js/jquery.sparkline.js"></script>

    <script src="{{ STATIC_URL }}zumanji/js/zumanji.js"></script>

  </head>

  <body>

    <div class="navbar navbar-fixed-top">
      <div class="navbar-inner">
        <div class="container">
          <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </a>
          <a class="brand" href="{% url zumanji:index %}">Zumanji <small>Performance Tests</small></a>
          <div class="nav-collapse collapse">
            <ul class="nav">
              <li><a href="{% url zumanji:index %}">Home</a></li>
            </ul>
          </div><!--/.nav-collapse -->
        </div>
      </div>
    </div>

    <div class="container">
      {% block content %}
      {% endblock %}
    </div> <!-- /container -->


    <footer id="footer">
      <div class="container">
        {% block footer %}
          <a href="https://github.com/disqus/zumanji">Zumanji</a> is Open Source Software | A tribute to <a href="http://twitter.com/zmanji">@zmanji</a>, the greatest <a href="http://code.disqus.com" style="text-decoration:line-through">DISQUS</a> intern ever.
        {% endblock %}
      </div>
    </footer>

    {% block scripts %}{% endblock %}

  </body>
</html>
