{% load zumanji_helpers %}

<tr>
  <td>
    <a href="{% url zumanji:view_test project_label=test.project.label build_id=test.build.id test_label=test.label %}?compare_with={{ compare_build.id }}">{{ test.shortlabel }}</a>{% if test.num_tests %} <small>({{ test.num_tests }} tests)</small>{% endif %}
  </td>
  {% for coldata in columns %}
    <td style="text-align:center; vertical-align:middle;">
      {% if coldata %}
          {{ coldata.0|floatformat:2 }}s<br><small>{{ coldata.1 }} calls</small>
      {% else %}
          &mdash;
      {% endif %}
    </td>
  {% endfor %}
  <td style="text-align:center; vertical-align:middle;">{{ test.mean_duration|floatformat:2 }}s</td>
  {# <td style="text-align:center;"><span class="sparkline" data-height="40px" data-values="{{ test.historical|format_historical }}"></span></td> #}
</tr>